def print_red(text):
    print("\033[91m {}\033[00m".format(text))

def print_green(text):
    print("\033[92m {}\033[00m".format(text))

def print_gray(text):
    print("\033[97m {}\033[00m".format(text))

def print_yellow(text):
    print("\033[93m {}\033[00m".format(text))

def print_pink(text):
    print("\033[95m {}\033[00m".format(text))
